@@ -19,6 +19,6 @@
 
 LIBDIR = r'/clangarm64/lib'
 DATADIR = r'/clangarm64/share'
-BUILDDIR = r'C:/M/B/src/build-aarch64-w64-mingw32'
-SRCDIR = r'C:/M/B/src/gst-devtools-1.24.11'
+BUILDDIR = r'C:/M/B/src/build-CLANGARM64'
+SRCDIR = r'C:/M/B/src/gst-devtools-1.24.12'
 GST_VALIDATE_TESTSUITE_VERSION = '1.24'
